#
# spec file for package python-openstacksdk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-openstacksdk
Version:        3.3.0
Release:        1.3
Summary:        An SDK for building applications to work with OpenStack
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/openstacksdk
Source0:        https://files.pythonhosted.org/packages/source/o/openstacksdk/openstacksdk-3.3.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PyYAML >= 3.13
BuildRequires:  python3-appdirs
BuildRequires:  python3-beautifulsoup4
BuildRequires:  python3-ddt
BuildRequires:  python3-decorator >= 4.4.1
BuildRequires:  python3-deprecation
BuildRequires:  python3-dogpile.cache >= 0.6.5
BuildRequires:  python3-extras
BuildRequires:  python3-fixtures
BuildRequires:  python3-jmespath >= 0.9.0
BuildRequires:  python3-jsonpatch >= 1.16
BuildRequires:  python3-jsonschema
BuildRequires:  python3-keystoneauth1 >= 3.18.0
BuildRequires:  python3-munch
BuildRequires:  python3-netifaces >= 0.10.4
BuildRequires:  python3-os-service-types >= 1.7.0
BuildRequires:  python3-oslo.config
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-platformdirs >= 3
BuildRequires:  python3-python-subunit
BuildRequires:  python3-requests-mock
BuildRequires:  python3-requestsexceptions >= 1.2.0
BuildRequires:  python3-statsd
BuildRequires:  python3-stestr
BuildRequires:  python3-stevedore
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch
%if 0%{?suse_version}
# RDO does not package prometheus_client
BuildRequires:  python3-prometheus_client
%endif

%description
The openstacksdk is a library for building applications to work
with OpenStack clouds.
The project aims to provide a consistent and complete set of
interactions with OpenStack's many services, along with complete
documentation, examples, and tools.

%package -n python3-openstacksdk
Summary:        An SDK for building applications to work with OpenStack
Requires:       python3-PyYAML >= 3.13
Requires:       python3-appdirs
Requires:       python3-cryptography >= 2.7
Requires:       python3-decorator >= 4.4.1
Requires:       python3-dogpile.cache >= 0.6.5
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-jmespath >= 0.9.0
Requires:       python3-jsonpatch >= 1.16
Requires:       python3-keystoneauth1 >= 3.18.0
Requires:       python3-munch
Requires:       python3-netifaces >= 0.10.4
Requires:       python3-os-service-types >= 1.7.0
Requires:       python3-platformdirs >= 3
Requires:       python3-requestsexceptions >= 1.2.0
%if 0%{?suse_version}
Obsoletes:      python2-openstacksdk < 1.0.0
%endif
%if 0%{?suse_version}
%if 0%{?sle_version} >= 150000 || 0%{?suse_version} > 1500
Requires:       mkisofs
%else
Requires:       genisoimage
%endif
%else
Requires:       genisoimage
%endif

%description -n python3-openstacksdk
The openstacksdk is a library for building applications to work
with OpenStack clouds.
The project aims to provide a consistent and complete set of
interactions with OpenStack's many services, along with complete
documentation, examples, and tools.

This package contains the Python 3.x module

%package -n python-openstacksdk-doc
Summary:        %{summary} - Documentation
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-svg2pdfconverter

%description -n python-openstacksdk-doc
The openstacksdk is a library for building applications to work
with OpenStack clouds.
The project aims to provide a consistent and complete set of
interactions with OpenStack's many services, along with complete
documentation, examples, and tools.

The openstacksdk is a collection of libraries for building
applications to work with OpenStack clouds.

%prep
%autosetup -p1 -n openstacksdk-3.3.0
%py_req_cleanup
sed -i -e 's,coverage.*,,' test-requirements.txt || true
sed -i -e "s,'sphinx.ext.intersphinx'\,,," doc/source/conf.py
%if !0%{?suse_version}
# RDO does not package prometheus_client
rm openstack/tests/unit/test_stats.py
%endif

%build
%py3_build
PBR_VERSION=3.3.0 %sphinx_build -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%py3_install

%check
export OS_LOG_CAPTURE=true
export OS_TEST_TIMEOUT=30
rm -v openstack/tests/unit/test_hacking.py
%{openstack_stestr_run}

%files -n python3-openstacksdk
%license LICENSE
%doc ChangeLog README.rst
%{_bindir}/openstack-inventory
%{python3_sitelib}/openstack
%{python3_sitelib}/*.egg-info

%files -n python-openstacksdk-doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 3.3.0
  - baremetal: Decode 'config_drive' argument to 'set_provision_state'
  - cloud: Trivial fixes
  - Add Tap Mirrors to SDK
  - Allow project switching for Designate API
  - tox: Don't install package in pep8
  - image: Pass correct stores argument
  - compute: Add Server.clear_password action
  - Remove retired project Senlin job
  - Allow tags to be passed through to compute.create_server
  - docs: Add missing identity v3 proxy API docs
  - compute, block storage: Minor fixes to limits
  - compute: Add additional options to Server.rebuild
  - compute: Correct base path for default, detailed quotas
  - reno: Update master for unmaintained/zed
  - compute: Add additional server create parameters
  - compute, block storage: Add support for quota class sets
  - compute, volume: Improve 'update_quota_set'
  - pre-commit: Add pyupgrade hook
  - Fix multiple image_id query mappings
  - Combine 3 auto_allocated_topology tests into one test
  - compute: Add support for legacy 'onSharedStorage' param
  - Adding SDK support for ``glance md-namespace-objects-delete``
  - baremetal: Adds list node firmware support
  - Add support for federation service providers
  - Fix AttributeError in delete_limit method
  - volume: Allow passing a volume type object to retype_volume
  - cloud: Remove use of OpenStackCloudCreateException
  - Run auto_allocated_topology functional tests in the own project
  - Use mypy syntax compatible with older pythons.
  - tests: Rework warnings-related tests
  - Add Binero public cloud to vendor
  - pre-commit: Bump versions
  - volume: Allow setting volume statuses individually
  - cloud: Do not reference other cloud mixin's methods
  - volume: Add ability to set, unset image metadata
  - Remove mypy union line which breaks older pythons.
  - Add Binero public cloud to vendor support
  - Allow filtering BGPVPNs
  - trivial: Prepare for pyupgrade pre-commit hook
  - image: make sure the target for "clear_cache" is valid
  - README: Add guide on raw HTTP layer
  - [func test] Fix race between attachment delete and server delete
  - compute: Add server tag proxy methods
  - Fixed update_metadef_object
  - hacking: Add check for deprecated exception types
  - Identity: Add support for inherited_to for role_assignments
  - Extend project cleanup
  - Add quota class set to shared file system
* Thu May  2 2024 cloud-devel@suse.de
- update to version 3.1.0
  - Implemented heat 'stack suspend' and 'stack resume' function
  - Fix: Update/Delete type encryption operation
  - config: Add missing space to warning
  - mypy: Address issues with openstack.orchestration
  - Remove unnecessary `keys` calls
  - [baremetal] Add some missing fields to node object
  - identity: Add test for 'role_assignments_filter' proxy method
  - Resource locks and access rules restrictions
  - reno: Update master for unmaintained/yoga
  - Add support for showing requested az in output
  - Add volume transfer support [2/2]
  - mypy: Address issues with openstack.network
  - identity: Add access rule CRUD support
  - connection: Fix typo
  - Add snapshot manage unmanage support
  - mypy: Address issues with openstack.compute
  - Add sort_key and sort_dir to core Neutron resources
  - Add volume manage support
  - Adding SDK support for ``glance md-namespace-properties-delete``
  - mypy: Address issues with remaining service modules
  - tests: Remove unused hook
  - [baremetal] Add missing owner attribute to allocation
  - Fix project cleanup for routers with static routes
  - Fix the mailing list domain in documentation link
  - mypy: Address issues with openstack.block_storage
  - mypy: Address issues with openstack.clustering
  - mypy: Add typing to openstack._log
  - zuul: Switch bifrost job to jammy
  - Add support for provider_id for volume objects
  - [baremetal] Add support for service steps
  - Check Designate API version for shared zones tests
  - Enforce endpoint override for services without discovery
  - Return the results of init attachment request
  - Fix list of server migrations
  - Support the API for managing external gateways
  - volume: Add Limit to volume v2 API
  - compute: Add 'locked_reason' to Server resource
  - cloud: Replace use of aliased exceptions
  - fakes: Generate correct type for list type components
  - Add missing snapshot parameters
  - mypy: Address issues with openstack.baremetal, baremetal_introspection
  - reno: Update master for unmaintained/victoria
  - [baremetal] port add shard, is_smartnic, name
  - Drop support for Python 3.6
  - docs: Add docs on configuration of a service user
  - Update master for stable/2024.1
  - requirements: Sort alphabetically
  - Implement heat 'stack event list'
  - Incorrect protocol type in create_security_group_rule()
  - mypy: Address issues with openstack.identity
  - Remove importlib-metadata from requirements
  - reno: Update master for unmaintained/wallaby
  - tox: Correct functional test factors
  - Add volume transfer support [1/2]
  - Fix markup syntax in docstring
  - mypy: Address issues with openstack.object_store
  - reno: Update master for unmaintained/xena
  - pre-commit: Bump linter versions
  - [baremetal] driver add missing firmware interface
  - Switch back to LaunchPad for issue tracking
  - mypy: Address issues with openstack.image
  - Fix typo
  - Remove resource_key for dns floating IP
* Fri Dec  1 2023 cloud-devel@suse.de
- update to version 2.0.0
  - [baremetal] Add firmware_interface support
  - block storage: Add missing docstrings
  - tests: Move cloud-layer service tests to their own file
  - tests: Update functional tests for resource providers
  - Bump the chunk_size to use CPU more efficiently
  - cloud: Remove floating network cache
  - [baremetal] Ensure baremetal shard parameter gets passed
  - cloud: Remove remnants of port caching
  - placement: Add support for traits
  - cloud: Remove '_object_store_client'
  - config loader: Prefer cli/env over clouds.yaml args for some args
  - volume: Add Extension to volume v2 API
  - Implemented methods for share metadata
  - docs: Add missing docs for block storage resources
  - block storage: Add support for services
  - mypy: Address issues with top-level files
  - Add support for default security group rules in SDK
  - volume: Add missing attributes to Extension
  - identity: Add support for domain config
  - cloud: Remove unnecessary types import
  - Rename share group snapshot 'members' method
  - Bump API version in Manila functional tests
  - placement: Add support for resource provider aggregates
  - Add image metadef object operations
  - tests: Rename file, remove unused file
  - docs: Add exception documentation
  - Fix bulk_delete support determination
  - cloud: Remove '_orchestration_client'
  - Fix Swift endpoint conversion to determine info/caps url
  - openstack.format: Remove 'serialize' classmethod
  - cloud: Ignore invalid filters
  - cloud: Convert 'get_volume_limits' to use proxy layer
  - fix memory leak of Connections
  - tests: Remove references to shade
  - Add "hardware_offload_type" attribute to "port"
  - wokflow: add update_workflow proxy method
  - docs: Document various warnings
  - docs: Add missing docs for identity resources
  - docs: Add missing docs for compute resources
  - docs: Use asterix for Network resources doc
  - Fix heat stack _action function to handle exception
  - cloud: Remove old cloud-layer caching functionality
  - tests: Enable UserWarning by default
  - [baremetal] Add support for querying for shards
  - support notification vmoves for masakari
  - docs: Add documentation for openstack.test.fakes
  - baremetal: Add missing docstrings
  - Run mypy as pre-commit
  - Fix manila access rules functional tests
  - Add fake resources generator
  - Treat server as a dict in add_server_interfaces
  - fix flavor.swap attribute type
  - Stop randomly sorting error lines
  - cloud: Remove dead code
  - tox: Bump min_version to 4.3.0
  - image: Add support for metadef property operations
  - block storage: Add query string params for many APIs
  - Define version for share_access_rules
  - Encode type of 'links' for Extension objects
  - Unused param in stack unit test
  - [baremetal] Add support for parent_nodes
  - Implement stack export in openstacksdk
  - cloud: Remove '_{service}_client' properties
  - [baremetal] Add unhold provision state verb support
  - docs: Improve docs for Connection with CONF object
  - Add 2 tls container params for Octavia Pools
  - docs: Rewrite caching docs
  - cloud: Remove '_is_client_version'
  - Add missing `return` in `upload_volume_to_image`
  - cloud: Remove '_get_raw_client'
  - Support passing a subnetpool for create_subnet
  - tests: Skip intermittently failing placement traits test
  - tox: Add environment documentation
  - Allow resources to be skipped on project cleanup
  - image: Fixed URL for stores_info
  - Add volume attachment support
  - VPN: add missing fields to VpnIpsecPolicy
  - Add fake proxy generator
  - cloud: Don't use dangerous argument defaults
  - Define version for export_locations
  - compute: Add missing docstrings
  - Fix: volume request body for scheduler hints
  - fakes: Add type hints
  - Return HTTP response for delete_access_rule.
  - Add SFC to SDK
  - fix block storage resource registry
  - cloud: Remove dead method
  - cloud: Remove remnants of floating IP caching
  - Support manage/unmanage shares with manila
  - cloud: Remove remnants of server caching
  - cloud: Filter FIPs by valid filters
  - cloud: Remove unnecessary '_make_unicode' helper
  - placement: Add support for resource provider inventories
  - Add Octavia support for HSTS
  - resource: Remove unused 'Resource.service' attribute
  - Cleanup logic to either dry-run, bulk_delete or do single object deletes
  - tests: Migrate tests from os-hosts to os-services
  - Remove _min_microversion for consistency
  - volume: Add Capability to volume v2 API
  - cloud: Reduce duplication
  - Add share group snapshots to shared file systems.
  - Update master for stable/2023.2
  - Adds share group resource to shared file system
  - Replace appdirs usage with platformdirs
  - exceptions: Remove unused exception
* Tue Jul 18 2023 cloud-devel@suse.de
- update to version 1.3.1
  - Use custom warnings everywhere
  - update rackspace profile to specify identity version
  - Fix broken python3.6 support
  - tests: Ignore our own deprecation warnings
  - Use custom warnings, not logging.warning
  - Prepare for hacking 6.x
  - Removing region Lon1. Updating block_storage_api_version. Adding image_format.
  - Add share network resource to shared file system
  - Remove "feature/r1" override from manila job
  - Blackify openstack.message
  - Add missing `force` parameter
  - Blackify openstack.container_infrastructure_management
  - cloud: create_server: fix scheduler_hints/group
  - config: Load additional options for v3multifactor
  - Remove usage of deprecated `sre_constants` module
  - fix docstrings refering to volume attachments instead of server migrations
  - Add link to image sharing api docs
  - add extended neutron job
  - Include "security_groups" to "Port" query parameters
  - config: Split 'OS_AUTH_METHODS'
  - pre-commit: Enable black
  - tox: Disable E501
  - Revert "Revert "Add "security_group_ids" to Port's query parameters""
  - Add 'callback' to 'wait_for_delete', 'wait_for_status'
  - docs: Replace/remove shade-specific docs
  - Rework zuul config
  - Add share access rules to shared file system
  - Blackify openstack.object_store
  - Update master for stable/2023.1
  - Blackify openstack.load_balancer
  - cloud: Rename shade-specific method
  - Blackify openstack.placement
  - Add BGPVPN to SDK
  - cloud: Remove '_ShadeAdapter'
  - Add Cleura acceptance tests
  - compute: Add Server.restore, restore_server proxy method
  - Blackify openstack.key_manager
  - Add support for Ironic node shard attribute
  - Blackify openstack.instance_ha
  - compute: Adds shelve-offload support
  - Add block storage summary support
  - Adding support for glance cache-queue Command
  - Blackify openstack.cloud
  - Drop legacy job that is always failing
  - Add find_share() for shared file system share resource
  - Blackify openstack.clustering
  - Add share snapshot instance resource
  - cloud: Remove ClusteringCloudMixin
  - tests: Use uuid, not randint
  - FWAAS: add Computed summary field to FirewallRule
  - utils: Add 'supports_version'
  - Use pre-commit for 'pep8' tox target, bump versions
  - Blackify openstack.baremetal, openstack.baremetal_introspection
  - Migrate warnings to openstack.warnings
  - Add support for glance cache
  - add a new vendor profile for the Swiss Open Telekom Cloud
  - Add export location resource to shared file system
  - Blackify openstack.image
  - Adds SDK support for ``glance cache-delete``
  - Fix Accept header for deleting Octavia load balancers
  - Blackify openstack.workflow
  - Added neutron fields to share network resource.
  - Blackify openstack.network
  - Blackify openstack.compute (tests)
  - Allow key overrides in create and fetch methods
  - Ignore black version bump
  - Blackify openstack.dns
  - Microversion 2.91: Support specifying destination host to unshelve
  - Bump black to 23.3.0
  - image: Don't envelope properties
  - cloud: Move identity-related helpers
  - ironic: Add support for Introspection Rules
  - Blackify openstack.accelerator
  - Change python3 jobs template to latest version
  - Add resize/extend share actions.
  - Blackify openstack.database
  - Blackify everything else
  - Blackify openstack.orchestration
  - Blackify openstack.compute
  - Fix typo
  - support None as expected status in wait_for_status
  - Add share network subnet resource to shared file system
  - Adds Support for ``glance cache-clear``
  - modify ovh and ovh-us vendor config
  - Add share instances to shared file systems
  - Adds support for node hardware inventory
  - Implement acceptance test job
  - fix connection.Connection finalizer
  - Add image metadef_resource_type into the registry
  - Blackify openstack.block_storage
  - Prepare acceptance tests for real clouds
  - nit: Correct name of variable
  - tests: Isolate tests from OS_CLOUD
  - ssh key change
  - Remove unnecessary quotes
  - tests: Silence warning
  - Add Designate (DNS) zone share API
  - Blackify openstack.identity
  - Ignore blackify changes
  - Blackify openstack.shared_file_system
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 1.0.1
  - baremetal: Add Node.inject_nmi method
  - Fix server topology and diagnostics
  - Revert "Add 'details' parameter to various 'find' proxy methods"
  - compute: don't pass networks: auto for older microversions
  - Drop munch dependency
  - Drop _normalize class
  - Move get_compute_usage to use proxy
  - Cron Triggers proxy
  - tox: Trivial fixes
  - Prepare release note for R1.0
  - image: Remove _base_proxy module
  - Whitelist cloud functional tests in acceptance
  - image: Add metadef resource type operations
  - Stop normalizing floating ips
  - Deprecate all of the compute image proxy APIs
  - Implement unified search_resources method
  - image: Modify signatures of various image methods
  - Add Tap Services and Flows to SDK
  - add flavor description to flavor_create
  - block storage volume resource
  - Update README to indicate COE resource/proxy support
  - Remove unnecessary mocks
  - Add identity.group_users method
  - image: Add 'store' argument to 'delete_image' proxy method
  - tests: Avoid potential aliasing of imports
  - Convert cloud layer to use COE proxy layer
  - compute/server: add support of target state for evacuate API
  - Introduce resource_registry in the proxies
  - Add missing block storage v2 'find_*' methods
  - Finish Magnum rework
  - Add BGP Speakers and Peers to SDK
  - Add magnum cluster templates resource
  - Update python testing classifier
  - Fix backup metadata management and update
  - Add 'details' parameter to various 'find' proxy methods
  - baremetal: Add Node console methods
  - Add 'all_projects' support to proxy layers
  - Add typing information and documentation
  - image: Prevent passing conflicts args to stage_image
  - Fix creation of protected image for old user code
  - docs: Add docstring to 'openstack' module
  - Update tox.ini for tox v4 compatibility
  - Rework network functional tests
  - compute: Add functional tests for volume attachments
  - docs: Add overview of supported services to README
  - Improve swift headers handling
  - Prevent sending None password on create_user
  - Revert "compute/server: add support of target state for evacuate API"
  - Normalise query strings passed to 'find_*' methods
  - image: Correct typo
  - Allow passing more arguments to create_port
  - Add query mappings for vpnaas resources
  - Move normalize security group to sg class
  - support nat_destination when attaching existing floating_ip to a server
  - image: Allow providing 'data' argument to image upload, stage
  - Move _normalize_coe_* into _coe class
  - compute: Add support for triggering crash dumps
  - image: Remove unsupported parameters from v1 proxy
  - image: Correct typo with 'get_import_info' proxy method
  - Fix server action request generation
  - Move normalize_server to compute mixin
  - Add additional_vips parameter for Octavia load balancers
  - Update Internap auth URL
  - Remove python-dev from bindep
  - image: Add missing image import options
  - Fix docs for class SecurityGroupRule
  - image: Reformat proxy modules
  - compute: Pass microversion for actions
  - image: Remove unnecessary abstractions
  - coe: Add support for clusters
  - Accept queries when listing migrations
  - baremetal: Add Node boot_device methods
  - image: Allow listing detailed view of stores
  - Use /servers/detail endpoint in find_server proxy method
  - compute: Fix '*volume_attachment' proxy methods
  - Initialize tests of real clouds
* Mon Jan  2 2023 cloud-devel@suse.de
- update to version 0.102.0
  - compute: Default to 2.48 for server diagnostics
  - Added Ansible OpenStack Collection to Bifrost's job.required-projects
  - added api requirements for new "openstack image metadefs namespace list" command
  - resource: Reformat calls to request
  - docs: Trivial adjust index structure
  - Drop query parameter 'id' from identity mapping
  - Fix pre-commit issues
  - tests: Improve functional testing for image methods
  - Fix incremental backups handling in project cleanup
  - image: Add support for other metadef namespace operations
  - Support unknown attributes in resource.__getitem__
  - Migrate register_machine to use the proxy layer
  - docs: Add missing docs for proxy helper methods
  - Allow passing explicit microversions to Resource methods
  - Add docstring to wait_for_load_balancer() method
  - Allow Resource.to_dict to allow returning unknown values
  - network: Rename ikepolicy module
  - block storage: Add support for the GroupSnapshot resource
  - image: Trivial grouping of image proxy methods
  - trivial: Correct some docstrings
  - baremetal: rework node creation to be closer to the backend
  - resource: Remove unused helper, variable
  - Replace base64.encodestring with encodebytes
  - tests: Remove unnecessary service check
  - volume: Trivial docstring fixes to 'wait_for_status'
  - Extend project cleanup
  - block storage: Add update_volume proxy method
  - Add Python3 antelope unit tests
  - workflow: Trivial fix doc title
  - Update master for stable/zed
  - Use /volumes/detail endpoint in find_volume proxy method
  - Add support for fault object per Server API
  - Add support for updated_at field for volume snapshots
  - network: Remove duplicate module, update references
  - Allow to attach a floating ip to a specific fixed address
  - Update register_machine to use the Ironic format for ports
  - Implement project cleanup for object-store
  - Improve project cleanup for cinder
  - Actually use openstacksdk from source in the Bifrost job
  - resource: Fix pagination of nested Glance resources
  - docs: Correct docs for VpnIpsecPolicy
  - image: Add metadef schema resource to v2 api
  - Unify resource list filtering
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 0.101.0
  - Fix Baremetal cloud layer
  - Do not log to stdout by default
  - Fix python-dev reference in bindep
  - Add VPNaaS Endpoint Group resource
  - compute: Add support for instance actions
  - cloud: Remove a load of normalize helpers
  - Change title for "unreleased" renos
  - Reorg existing vpnaas content
  - Add VPNaaS IpsecPolicy resource
  - Allow to pass description parameter to cloud.create_server()
  - remove unicode prefix from code
  - cloud: Update docstrings for image functions
  - Remove unused normalization helpers
  - cloud: Update docstrings for accelerator functions
  - trivial: Run some files through black
  - Add network address_group proxy doc and unit tests
  - block storage: Add support for the Group resource
  - Allow unknown attributes in project resources
  - Enable add_ips_to_server() and _needs_floating_ip() for pristine server resources
  - docs: Add missing docs for block storage v3 proxy APIs
  - cloud: Update docstrings for compute functions
  - network RBAC policy: allow query for target tenant
  - Replace deprecated failUnlessEqual with assertEqual
  - Reduce list_router_interfaces() to necessary API calls
  - proxy: Resolve a TODO
  - cloud: Update docstrings for network functions
  - Add CRUD methods for Neutron router ndp proxy
  - Restore functionality to attach multiple floating ips with add_ip_list()
  - resource: Merge unnecessary separation of logic
  - cloud: Update docstrings for identity functions
  - cloud: Update docstrings for object store functions
  - Warn when no statsd library available
  - cloud: Update docstrings for block storage functions
  - Make nodepool jobs non voting
  - compute: Add support for os-simple-tenant-usages API
  - tests: Add pointers to docs on running tests
  - Add update capabilities to Snapshots
  - Disable deprecation warning for tenant_id
  - block storage: Add support for group type specs
  - Rework caching
  - compute: Correct some docstrings
  - test: Remove duplicated tests
  - Fix object upload for RAX
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 0.99.0
  - Fix functional test for user message
  - Block storage - reunite :class: links on single lines
  - Splits class `TestPlacementProxy`
  - compute: Server group rules are dicts, not lists of dicts
  - Skip qos-pps-minimum tests if extension is missing
  - network: Fix update of network provider
  - Improve StatsD metric precision
  - Get rid of normalization for image service
  - Add "security_group_ids" to Port's query parameters
  - Switch update_server cloud layer to proxy
  - Splits class `TestOrchestrationProxy`
  - Cloud / Compute service - reindentation of the docstrings
  - Database service - reindentation of the docstrings
  - Fix misuse of assertTrue
  - Improve compute flavor handling
  - Adds storage pools to shared file system
  - exception: Correct argument
  - Shared File System - reindentation of the docstrings
  - Reindentation of the docstrings for baremetal service
  - Replace the 'try except' block
  - tests: Handle overridden 'verify_delete' (kw)args
  - Switch quota methods of cloud layer to proxy
  - Start splitting the `TestImageProxy` class
  - Network - reindentation of the docstrings
  - Splits class `TestInstanceHaProxy`
  - Fix import order in identity tests
  - Cloud / Network service - reindentation of the docstrings
  - Splits the `TestBaremetalProxy` class
  - Splits class `TestMessageProxy`
  - Extend has_version function to accept version parameter
  - Fix import order in block_storage tests
  - Fix import order in orchestration tests
  - Support description in sg-rule creation
  - Add user message to shared file system
  - Functional tests for vpn ike policy resource
  - Add missing headers in object store
  - Identity: Add support for system role assignment
  - Cloud / Floating service - reindentation of the docstrings
  - Add revert share to snapshot to shared file system.
  - Indentation of the docstrings
  - Add limit resource to shared file system
  - Image service - reindentation of the docstrings
  - fix: improperly encoded object names
  - Add QoS min pps rule object and CRUD operations
  - Cloud / Dns service - reindentation of the docstrings
  - Network service - reunite :class: links on single lines
  - resource: Rewrap function signatures
  - Switch unittests for BS to use v3
  - Run nodepool job
  - compute: Add support for migrations API
  - Fix setting initial object/container metadata.
  - Restore get_compute_limits backward compatibility
  - Switch cloud.compute.get_server_by_id to use proxy
  - tests: Centralize configuration of default flavor, image
  - trivial: Typo fixes
  - Allow to filter endpoints by region_id
  - Instance HA service - reunite :class: links on single lines
  - Switch create_server cloud method to proxy
  - Keep creating keystone admin endpoint for heat
  - Introduce common class for QuotaSet
  - Introduce QuotaSet in the compute service
  - Orchestration service - reunite class links (:class:) on one line
  - compute: Add support for microversion 2.89
  - Switch Swift cloud layer to proxy
  - Fix import order in clustering tests
  - Cloud / Normalize service - reindentation of the docstrings
  - doc: Remove references to 'examples' test env
  - Clustering - reindentation of the docstrings
  - fix creation of protected image
  - Cloud / Security group service - reindentation of the docstrings
  - Vpn ike policy resource
  - Splits class `TestNetworkProxy`
  - Get rid of normalization in network CL
  - Revive legacy job
  - Orchestration- reindentation of the docstrings
  - Get rid of normalization in compute CL
  - Add Neutron Local IP CRUD
  - Compute - reindentation of the docstrings
  - Switch delete_server cloud method to rely on proxy
  - resource: Remove deprecated 'allow_get' attribute
  - doc: Update testing documentation
  - Add Python3 zed unit tests
  - Add a manila functional check job
  - compute: Regroup proxy methods
  - Add share snapshot to shared file system.
  - Add QoS rule type filtering keys
  - Cloud / Baremetal service - reindentation of the docstrings
  - DNS - reindentation of the docstrings
  - Introduce QuotaSet in block storage service
  - Fix key generation for caching
  - Add R1 summary release note
  - Cloud / Utils service - reindentation of the docstrings
  - trivial: Correct docstrings for 'delete' proxy calls
  - Optimize code by moving misc functions to utils
  - Add query parameters to local ip
  - Add user group assignment support in identity
  - Splits class `TestSharedFileSystemProxy`
  - image: Add "id" filter for images
  - Skip tests when needed extensions are disabled
  - Identity service - reunite :class: links on single lines
  - Shared file system - reunite :class: links on single lines
  - Revert "Add "security_group_ids" to Port's query parameters"
  - Cloud / Identity service - reindentation of the docstrings
  - Add common metadata mixin to block storage and clustering
  - Splits class `TestKeyManagerProxy`
  - Use empty read_acl for swift container
  - Make metadata a common mixin
  - Add support for updated_at field for volume objects
  - Remove '__unicode__' helper
  - Correct documentation about Load Balancer API
  - Switch compute limits cloud to proxy
  - Update master for stable/yoga
  - compute: Add support for server migrations API
  - Switch quota_set cloud layer BS methods to proxy
  - Get rid of normalization in orchestration CL
  - Fix import order in cloud tests
  - Move tag mixin into the common
  - Reindentation of the docstrings
  - Block storage - reindentation of the docstrings
  - Rely on proxy for compute.flavor cloud layer operations
  - Cloud / Coe service - reindentation of the docstrings
  - Load balancer - reindentation of the docstrings
  - Get rid of normalization in identity CL
  - Get rid of normalization in further CL services
  - Object Store - reindentation of the docstrings
  - Switch rebuild_server cloud method to rely on proxy
  - Splits the `TestAcceleratorProxy` class
* Tue May 24 2022 cloud-devel@suse.de
- update to version 0.61.0
  - Add "check_limit" to network Quota class
  - Update master for stable/xena
  - compute: Add support for server lock reason
  - compute: Add support for microversion 2.89
  - Change image.hw_qemu_guest_agent to be string
  - Fix some docstrings, and a small bug
  - Vpn ike policy resource
  - Add Python3 yoga unit tests
  - Keep creating keystone admin endpoint for heat
  - Add compute microversion 2.78
  - Add Neutron Local IP CRUD
  - Remove misspelled speccing arguments
  - Adds "test_update_zone" test case
  - Splits class `TestNetworkProxy`
  - Add support for reading node's "boot_mode" and "secure_boot" fields
  - Add support for changing baremetal node's boot_mode and secure_boot states
  - Add description args for device profile create
  - Changed minversion in tox to 3.18.0
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 0.59.0
  - Add support for API Extensions
  - Add support for project options
  - Add pre-commit
  - Update master for stable/wallaby
  - Add compute microversion 2.77
  - Add IPsecSiteConnection resource and proxy layer functionality for it
  - Improve README to provide example of Resource usage
  - Fix more import order in tests
  - placement: Add support for resource providers
  - Add support for Resource Filters
  - tests: Remove final use of 'TestProxyBase._verify'
  - Apply import order in some tests
  - Don't send empty remote_address_group_id for security groups
  - Drop jobs failing for too long
  - tests: Remove dead code
  - Temporarily disable nodepool job
  - Allow unknown attributes to be included in request body
  - Drop lower-constraints job
  - Apply import order in more tests
  - Fix import order in message and workflow unit tests
  - Switch to openstack-python3-xena-jobs template
  - Fix more import orders
  - Revert tags query_params back to tag
  - Fix import order in accelerator and config unit tests
  - Extend has_version function to accept version parameter
  - tox: Enable parallel docs build
  - Add deploy_steps to baremetal node provisioning
  - Add support for the GroupType resource
  - Adding retype_volume to BlockStorageCloudMixin
  - Increase RAM for the Ironic CI jobs
  - Cache auth token in keyring
  - Move to OFTC
  - Fix key generation for caching
  - Add support for the Neutron L3 conntrack helper API
  - Add min_count and max_count attributes to Server
  - docs: Add intro doc to user guide
  - placement: Add support for resource classes
  - Added support for the Capabilities resource
  - Prepare separate block_storage v3 documentation
  - Adjust image _base_proxy condition
  - Added support for the Limits resource
  - Fix import order in compute unit tests
  - Fix import order in load_balancer unit tests
  - Fix MFA authorization
  - Fix get_server_password method
  - Remove references to 'sys.version_info'
  - Add compute microversion 2.79
  - Fix typo - _list lists, doesn't delete
  - Apply pep8 import order style
  - Add set_readonly_volume to BlockStorageCloudMixin
  - Add compute microversion 2.57
  - setup.cfg: Replace dashes with underscores
  - Implement driver vendor passthrough
  - tests: Rename 'TestProxyBase._verify2' to '_verify'
  - Adds Node Vendor passthru
  - Avoid prometheus metrics explosion
  - Allow for override of statsd/influxdb settings per cloud
  - Fixing more import orders
  - Use py3 as the default runtime for tox
  - statsd: use timedelta and pipeline
  - tests: Sanity check 'test_proxy_base'
  - Fix import order in network unit tests
  - Extend functional test of image
  - Add tags option to the image upload
* Sun May  2 2021 cloud-devel@suse.de
- update to version 0.55.0
  - Skip address group functional tests if no extension
  - Volume Target support for Ironic on OpenStack SDK
  - Update master for stable/victoria
  - Follow-up on 751234 and 750072
  - Switch flavor ops in the cloud layer to proxy
  - Add ALPN support to load balancer listener
  - Fix l-c testing for ubuntu focal
  - Replace assertItemsEqual with assertCountEqual
  - Fix a trivial error in one of the error messages
  - Add _max_microversion for aggregates
  - Add ``device_profile`` attribute to ``port``
  - Prevent the endless loop in resource listing
  - Fix invalid assertIsNotNone statement
  - Update TOX_CONSTRAINTS_FILE
  - Respect default microversion in the microversion negotiation
  - Fix the invalid if statement
  - Add compute microversion 2.70
  - Add TODO to remove md5 wrapper
  - Set resource URI properties in listing method
  - add cluster_id to filter by cluster_id when list actions
  - Add update_flavor method
  - Remove duplicate test_zone_create
  - Add shared file systems support
  - Drop .json suffix from networking URLs
  - Move 'collections.Mapping' to 'collections.abc'
  - Trival change: Correct some errors
  - New volume availability zone resource, new functional and unit tests
  - Add tls_enabled param for Octavia Pools
  - Fix hacking min version to 3.0.1
  - Support waiting for bare metal power states
  - Complete compute.service operations
  - Add "description" to cinder volume types.
  - Refresh deprecated link
  - Update Open Telekom Cloud vendor docu
  - Fix a bogus error in config loader when using several args with dashes
  - Add func test for compute microversion 2.3
  - Add additional compute flavor operations
  - Change nodepool job to build CentOS-8-stream (unblock gate)
  - Add source_ip_prefix and destination_ip_prefix to metering label rules
  - Support roles 'name' in list_roles call
  - [Trival]: Add comments in the cloud/accelerator
  - Deprecate 'remote_ip_prefix' parameter in metering label rules
  - Add new Open Telekom Cloud region into the profile
  - Migrate ironic job to focal
  - Add support for overriding list base_path in find function
  - Add some compute console operations
  - Include "fields" to "Port" query parameters
  - Add support for updating Block Storage Volume type extra_spec attributes
  - Modify cloud.get_aggregate to use proxy.find
  - add masakari enabled to segment
  - Improve Ironic API on OpenStack SDK
  - Fix invalid argument formatting in log messages
  - Complete compute.hypervisor functions
  - Repair 2 deprecation warnings
  - Add id query parameter to sg rules
  - Add ALPN support to load balancer pools
  - Support SNAP_REAL_HOME when using openstacksdk inside a snap package
  - Switch cloud.networking.qos* operations to rely on proxy layer
  - Squeeze SnapshotDetail class into Snapshot
  - encapsulate md5 calls for fips
  - Add neutron address group CRUD
  - Add user_id as optional param to keypair operations
  - Apply urllib.parse.quote in unittests to get_mock_url
  - Remove unnecessary string formatting
  - Don't set list_type to dict for server groups.
  - Remove install unnecessary packages
  - Expand user path when loading SSL-related files
  - Increase IRONIC_VM_SPECS_RAM to avoid KP
  - Drop swift check for volume backup
  - Change microseconds to total_seconds()
  - Add 'project_id' to Snapshot query parameters
  - Complete compute aggregate functions
  - Add support for updating cinder (v3) volume types
  - Add query parameters to listing heat stacks
  - Support remote address group in SG rules
  - Support Deploy Templates for Ironic API
  - Fix exception parsing when using WSME
  - Add tests for compute microversion 2.2 and 2.10
  - Disable dstat on ironic job
  - Switch nodepool test to containers
  - Add support for Block Storage (v3) VolumeType Encyption resources
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 0.50.0
  - Add query parameter 'id' for security_groups
  - Fix l-c testing for ubuntu focal
  - Don't error if clouds.yaml is not readable
  - Set BaseImageProxy.create_image validate_checksum default to False
  - Add support for multiple image stores
  - Add "numa_affinity_policy" attribute to "port"
  - Fix a bogus error in config loader when using several args with dashes
  - Refresh python versions
  - Add compute microversion 2.6 and 2.8
  - Update TOX_CONSTRAINTS_FILE for stable/victoria
  - OpenStack port decorator variables
  - Use unittest.mock instead of mock
  - Strip self from incoming glance properties
  - Tolerate images created with other means
  - Fix issues found by latest flake8
  - Update master for stable/ussuri
  - Fix AttributeError exception during authorization
  - Extend statistics reporting
  - NIT: Fix application credential
  - baremetal: support for volume connectors API
  - Remove neutron-fwaas from the jobs' required project
  - Drop python3.5 support
  - Fix deleting stacks by id when waiting for result
  - baremetal: use proxy methods in unregister_machine
  - Fix image owner field
  - added new regions for provider OVH
  - Add block_storage find functions
  - Add support for filters into the project cleanup
  - Stop subclassing object
  - Add some unit tests for config.loader
  - Remove enforcer
  - Add cipher list support for octavia
  - switch to importlib.metadata for entrypoint loading
  - Update docs to work with newer Sphinx
  - Add user_projects method to docs index
  - Update .gitreview for stable/victoria
  - Wait for the project cleanup to complete
  - Add "id" to Port's query parameters
  - Remove some unneeded things from test-requirements
  - Fix metric names in the object_store
  - Add TLS protocol support for Octavia
  - Make optional name and admin password
  - Remove uses of from six.moves
  - Upload image via interop import if needed
  - Ignore IPv6 addresses if force_ipv4 is set
  - Allow passing in a logging handler
  - Add name query filter to keystone service
  - Switch to newer openstackdocstheme and reno versions
  - Add ansible stable-2.9 job and run 2.8 and 2.9
  - Functional tests to explicitly use ML2/OVS
  - Do not clean keypairs in the project cleanup
  - Update config to Keystone v3
  - Stop falling back to image import
  - baremetal-introspection: allow fetching unprocessed data
  - Don't use random.SystemRandom in tests
  - Remove use of six
  - Fix an unstable bare metal unit test
  - add default user and project domain for OVH provider
  - new ovh-us provider for OVH US regions
* Tue May 12 2020 cloud-devel@suse.de
- removed 0001-Increase-test-timeout-for-2-tests-in-TestImageProxy-.patch
- update to version 0.46.0
  - Add method for bulk creating objects.
  - Add router add/remove route operations
  - Keep connection backrefs with weakref.proxy
  - Increase test timeout for 2 tests in TestImageProxy class
  - Update the constraints url
  - Add Octavia quota to the SDK docs
  - Fix microversion negotiation in some bare metal node call
  - Add bulk port create.
  - Add support for additional volume backup options
  - Add application credential CRUD support
  - Fix the wrong doc use oslo_conf param
  - Run fetch-subunit-output role conditionally
  - Add a non-voting ironic-inspector job
  - Fix server for later microversion
  - Support for stateless security groups
  - Add availability_zone param to load balancer
  - Fix duplicated words issue like "was not not found"
  - Support uploading image from data and stdin
  - Remove duplicate job definition
  - Add allowed_cidrs param to load balancer listener
  - Fix aggregate functional test for id restriction
  - Change of auth url and regions
  - Raise hacking to 2.x
  - Add availability zone and availability zone profile resources to load balancer
  - Replace six.iteritems() with .items()
  - Update deps for tox venv target
  - Include user_id attribute in volume information
  - Lay a foundation for the project cleanup
  - Add reset_interfaces argument to patch_node
  - fix "How To Contribute" url
  - Revert "Switch to futurist for concurrency"
  - Update master for stable/train
  - Add clustering update_action
  - Add unit test for rackspace block-storage workaround
  - Add support for Federation Protocols
  - Switch stable ansible job to 2.8
  - Build PDF docs
  - baremetal node: 'error' is a failed state
  - Add bulk creation of rules for Security Group.
  - Add support for Node tainted field
  - Use the bifrost bionic CI job
  - Start supporting type info
  - "qos_network_policy_id" attribute added to port resource
  - Include "fields" to "SecurityGroup" query parameters
  - Consistent normalization of Machine objects in the cloud layer
  - baremetal: fail-less mode for wait_for_nodes_provision_state
  - Re-add nodepool functional test
  - Update Rackspace vendor profile for cinder v2
  - Volume.backup API attr name fixes
  - Switch to Ussuri jobs
  - Update to hacking 3.0
  - baremetal-introspection: add manage_boot argument to start_introspection
  - Rationalize examples and functional extra config loading
  - Added missing {user, project}_domain_name in Api
  - Update local hacking checks
  - Switch to futurist for concurrency
  - Add support for Identity Providers
  - Implement If-Match support for Neutron resources
  - Normalise create_coe_cluster{,_template} results
  - Replace assertItemsEqual with assertCountEqual
  - Add port property: ip_allocation
  - Import generate_temp_url from swiftclient
  - Fix error handling in network trunks operations
  - Use generated list of services instead of metaclass
  - Fix .. note:: rendering in doc
  - Extract check temp_url_key logic
  - Set max_microversion to 2.53 for hypervisors
  - Re-add functional tests on flavor content
  - Make proxy honor raise_exc in REST primitives
  - Make the bifrost job non-voting
  - Handle HTTP errors in add/remove router interface calls
  - Turn off test log capture for now
  - Set min version to test node retirement
  - Cleanup doc/source/conf.py
  - Increase dogpile version for Py3.7 compatibility
  - Add description field to portforwarding NAT rules
  - Add support for not including the ID in creation requests
  - Return uuid alias for coe_cluster in non strict mode
  - Remove python2 from project-template
  - CI: add ironic-python-agent-builder to the ironic job
  - Fix service_type test for magnum in gate
  - Add dns_publish_fixed_ip attribute to subnets
  - Add support for federation mappings
  - Remove kwargs validation for identity project updates
  - Change default image type in the OTC vendor profile
  - Support vendor data in configdrive building
  - [tests] Improve devstack/post playbook efficiency
  - Bump the openstackdocstheme extension to 1.20
  - Fix: Set image name correctly if filename is not passed
  - Fix error handling on add/remove router iface calls
  - Fixes get_user when identity responses are paged
  - update OVH vendor entry
  - tox: Keeping going with docs
  - Add python-requires entry indicating 3.5 is required
  - Bump min version of decorator
  - Stop supporting python2
  - Handle old status-less placement service
  - Adding basic implementation for Accelerator(Cyborg)
  - Add retired and retired_reason fields to baremetal node
  - Fix bug in object storage container creation setting metadata
  - Remove extra python2 test jobs
  - Small cleanups after Python2 drop
  - Fail a job for ansible modules with message
  - Fix reno index list indent
  - Add Release notes entry for Identity v3 IDP, Mapping and Protocol
  - Add return cluster_id when query actions list
  - Expose baremetal Node.owner
  - Use has_service in functional test's require_service
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Mon Mar 23 2020 cloud-devel@suse.de
- update to version 0.36.2
  - Fix error handling in network trunks operations
  - Handle HTTP errors in add/remove router interface calls
  - Consistent normalization of Machine objects in the cloud layer
  - Fix error handling on add/remove router iface calls
  - Include "fields" to "SecurityGroup" query parameters
  - Use has_service in functional test's require_service
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/train
  - Fix microversion negotiation in some bare metal node call
  - Keep connection backrefs with weakref.proxy
  - Update .gitreview for stable/train
  - Fix server for later microversion
  - baremetal node: 'error' is a failed state
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Thu Oct 31 2019 Thomas Bechtold <tbechtold@suse.com>
- Add 0001-Increase-test-timeout-for-2-tests-in-TestImageProxy-.patch
  Increases test timeouts to fix unstable tests during build
* Wed Oct  9 2019 cloud-devel@suse.de
- removed 0001-baremetal-Add-support-for-mkisofs-and-xorrisofs-for-.patch
- removed 0001-add-python-3.7-unit-test-job.patch
- update to version 0.36.0
  - Fix image create with tags
  - Handle oslo.config exceptions in from_conf
  - baremetal: raise more specific ResourceFailure in wait_for_* methods
  - Adding dns_domain parameter into create_network
  - Support deleting all routes in update_router
  - DRY test_connection
  - Return None from get_server_by_id on 404
  - Replace nodepool func jobs
  - Add support for generating form-post signatures
  - Update master for stable/stein
  - Properly convert baremetal fields to server-side values
  - Actually pass on network_data when building configdrive
  - Add support for global_request_id
  - baremetal.configdrive: tolerate user_data as a string
  - Add support for vendor hooks
  - Cap sphinx for py2 to match global requirements
  - Allow replacing service implementation
  - Fix some typos
  - Fix typo for subnet.py
  - Link to baremetal API reference from patch_node
  - Allow limiting Connection service_types from oslo.config
  - Add a fields meta_data to result of Senlin API
  - Make PATCH a first class operation and support it for baremetal
  - Switch cloud layer to use proxy for DNS
  - Remove Accept header with empty value for HEAD and DELETE requests
  - Bump keystoneauth1 minimum to 3.16.0
  - Enable ansible module test for keypair to check return data
  - Return empty lists for resources if neutron doesn't exist
  - Update compute.server resource
  - Remove now unused task_manager file
  - Fix image deletion with tasks_api enabled
  - Expand on a brief error message
  - Add ability to provide qos_policy_id for port
  - Update betacloud vendor entry
  - Use Resource layer in cloud for SecurityGroups of server
  - Add set-boot-device to baremetal
  - Expose locked status for Server
  - Move Orchestration methods into Proxy
  - add python 3.7 unit test job
  - Add strict_proxies option for Connection
  - Update Limestone Networks vendor config
  - Adds missing "params" attribute for creating a Mistral workflow execution
  - Add support for all_tenants in OpenStackInventory
  - Revert "Revert "Replace TaskManager with a keystoneauth concurrency""
  - Add support for fields in baremetal get_* resources
  - Pin to latest os-service-types
  - Add floating IP port forwarding related methods
  - Make factory for a CloudRegion from CONF objects
  - Replace catalog-v3.json with keystoneauth fixture
  - Add 'tag' support to compute with supported microversion
  - Use Resource layer for network SecurityGroups
  - baremetal-introspection: fix passing a Node to start_introspection
  - Add access alias (aka) for the resource attributes
  - Support Proxy-specific region_name
  - Correct endpoint_override discovery for service with dashes in their type
  - Move the history lesson into the docs
  - Fix dns return values
  - Workaround older octavia version discovery
  - OpenDev Migration Patch
  - Uncap jsonschema
  - Support for the baremetal introspection service
  - Skip attaching FloatingIP if it is already attached
  - Increase randomness in ZONE creation
  - force specify project_id during create Sg_rule may cause issue
  - Add header to auto-delete image upload objects
  - Remove and rearrange object bonged proxy tests
  - Strip two more accept headers from object-storage
  - Specify store when importing an image
  - Split OpenStackCloud into reasonable pieces
  - Fix DeprecationWarning for using logger.warn
  - Fix bm tests: sort lists being compared
  - Remove outdated devstack section from docs
  - Cleanup split of openstackcloud
  - Fix invalid assert state
  - Rework statistics reporting
  - Add node traits support to baremetal
  - bug: avoid unnecessary object meta prefix
  - from_conf: fix handling service names with dashes
  - baremetal: Add support for mkisofs and xorrisofs for configdrive
  - fixing timing
  - Collect request stats
  - Use Resource layer for compute KeyPairs
  - Continue refactoring of the image
  - baremetal: allow updating name and extra fields of an allocation
  - Bail earlier on a version mismatch for a supported service
  - Clarify error if no version can be found
  - Deduplicate next-page URL's query params
  - Add CloudRegion helper method for arbitrary endpoints
  - Fix wait_for_server docstring
  - Move pep8 requirements in to test-requirements
  - Repair masakari FT
  - Removing region La1 from the list of regions.
  - Fix discovery cache sharing
  - Add image.stage methods
  - Minor fixups from from_conf changes
  - Can't create a metadata named key, clear, delete
  - Fix README example for cloud layer
  - Use Resource layer for the compute Hypervsors and Images
  - baremetal: implement the correct update of the maintenance_reason field
  - Add logger to Proxy object
  - docs: Add simplified CLI parser docs
  - Deprecate ServerDetails class
  - Retry large object manifest upload
  - Initalize pool_executor so close works
  - Collapse OpenStackSDKAdapter into Proxy
  - Validate that connect_as connects as the project
  - Allow deeper levels of nesting for pdf builds
  - Skip most service_description for unknown services
  - Rationalize endpoint_for and get_endpoint_from_catalog
  - Add unit tests for connection.add_service
  - Use Resource layer for next compute methods
  - Update links
  - Volume.Backup restore fixes
  - Add proxy API reference to baremetal user guide
  - Extract image download method into a mixin
  - Use Resource layer for compute AZ and Aggregates
  - Add Python 3 Train unit tests
  - Do not disregard tags when updating stacks
  - Set xenapi_use_agent to "False" instead of false
  - Replace use of log.warn with log.warning
  - Support skipping unknown QP
  - Support microversion 2.61 for nova flavors
  - Minor refactor cleanup of _make_proxy
  - Move set_temp_url_key logic into resource objects
  - Add release note for new disable service functionality
  - Get rid of unused _OpenStackCloudMixin.get_region
  - Try to fix the masakari CI job
  - Create runtime descriptor for new service
  - added support for binding:profile parameter in create_port/update_port
  - Replace openstack.org git:// URLs with https://
  - Avoid unnecessary object meta prefix in proxy
  - Update api-ref location
  - URL encode swift objects endpoints
  - Update baremetal to use proxy logger
  - Add "name" filter in "list" call when retrieving a single register
  - Fix AttributeError bug when creating nested stacks
  - Use auth_url as identity endpoint when not project scoped
  - Finish updating links to point to opendev
  - Add 'node' attribute to baremetal Allocation
* Fri Apr 12 2019 cloud-devel@suse.de
- added 0001-add-python-3.7-unit-test-job.patch
- added 0001-baremetal-Add-support-for-mkisofs-and-xorrisofs-for-.patch
* Wed Apr 10 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.27.0:
  * Replace TaskManager with a keystoneauth concurrency
  * Replace openstack.org git:// URLs with https://
  * Update UPPER\_CONSTRAINTS\_FILE for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 0.26.0
  - Fix query parameters of network.port_forwarding
  - Transform server with munch before normalizing
  - Add network segment range resource
  - Return retries on HTTP CONFLICT to baremetal.attach_vif_to_node
  - Fix bugs in debugging with Tox
  - Use pagination detection by default
  - Stop running grenade-py3
  - Add possibility to override base_path for resource operations
  - Remove unused Task classes
  - Add block_storage v3 API support
  - Fix syntax error with exception handling
  - use overriden base_path in remaining CRUD operations
  - Add wait functions to orchestration proxy
  - Add support for octavia's resuorces quota
  - Document "Role Assignment Operations"
  - Rename compute.service.zone to availability_zone
  - Update cirros version for functional tests
  - Fix pagination key detection
  - Drop self.conn from base.TestCase
  - Test python2 with py27
  - Make delete_unattached_floating_ips return a count
  - Add functional tests for masakari
  - Properly munch for resource sub-dicts
  - Add host aggregate missing functions
  - Skip block storage v2 functional tests for a minute
  - Slightly refactor vendor profile loading
  - Make timeouts in functional tests configurable
  - Bug : identity v3 Proxy role assignments only support instances.
  - Fix latest flake8 issues
  - Add port property: port-resource-request
  - Check result of server metadata operation
  - Add agent property: resources-synced
  - Refactor tag support
  - Fixed incorrect exception raising in configdrive generation
  - Filter ports in list_ports when batching is in effect
  - Added server diagnostics
  - Added basic CRUD functionality around Host Aggregates
  - Make tox tips job actually run sdk tests
  - Make sure we pick flavors with disk
  - Unpin dogpile.cache
  - Support dict of links in pagination detection
  - Support remote vendor profiles
  - Fix dogpile.cache 0.7.0 interaction
  - Change openstack-dev to openstack-discuss
  - Update min tox version to 2.0
  - Add baremetal Node fields from versions 1.47 - 1.49
  - Add missing properties for role
  - Use retriable_status_codes in image upload
  - [Trivial Fix] Correct spelling error of "bandwidth"
  - Start using direct REST in normalize tests
  - Fix the misspelling of "configuration"
  - Compute location properly in server
  - Fix requesting specific fields from ironic
  - Fix for not released thread in service_description
  - handle "paginated" argument in test_list properly
  - object_store: exposes the prefix parameter
  - Add support for bodyless commits
  - Add image attributes from v2.7
  - Add Octavia (load_balancer) flavor API
  - fix typos
  - Fix some spelling in documentation
  - Stop mocking method in fwaas test
  - Fix/Add : Identity V3 validate user role
  - Import code for building ironic-compatible configdrives
  - Add image.schema resource
  - Use mock context in test_fwaas
  - Fixes for Unicode characters in python 2 requests
  - Deal with double-normalization of host_id
  - baremetal: implement set_node_power_state in the proxy
  - Change approach to detailed listings of baremetal resources
  - implement identity v3 Proxy "unassign_project_role_from_user"
  - Turn off unneeded devstack services
  - baremetal: support for allocation API
  - Shift swift segment async code out of adapter
  - implement block-storage backup resource
  - Fix for not released thread in get_session_client
  - Add support to get recovery workflow details
  - implement identity v3 Proxy group role management
  - Adds kwargs support when creating a Neutron subnet
  - Add a __main__ handler, version command
  - Fix minor issues in the baremetal proxy docs
  - Apply list filter fix to servers and floating ips too
  - Move image methods to sdk image proxy
  - Fix resource deletion in clustering
  - Add networks to Limestone vendor
  - Add propagate_uplink_status to port
  - Add image tasks schema methods
  - Move server munch transformation into normalize
  - Added Octavia load balancer and listener stats
  - Remove mocking workaround from adapter
  - Fix indentation for new pycodestyle E117
  - Fix the conflict of urlparse between python2 and python3
  - Use sdk for list_servers
  - Tweak find_image method to search in hidden images
  - Adds prefixlen to the request body when creating subnets
  - Advancing the protocal of the website to HTTPS in compute.rst.
  - Document "insecure" flag
  - Remove setup.py check from pep8 job
  - fix typo
  - Adds tags support for Octavia (load_balancer)
  - Make Connection a context manager
  - Make all resource locations process project_id
  - Add image.task resource
  - do not force interface=admin for identity api v3
  - Add close method to shutdown threadpool
  - Restrict inventory test to devstack-admin
  - Add a non-voting job with metalsmith
  - Add Octavia (load_balancer) flavor profile API
  - Add Octavia (load_balancer) amphora API
  - Add Octavia (load_balancer) load balancer failover
  - Revert "Replace TaskManager with a keystoneauth concurrency"
  - baremetal: support network_data when building configdrive
  - Fix raise create_server and attach to a network given a net-name param
  - Add glance image import support
  - Fix neutron endpoint mangling
  - Register proxy directly in add_service
  - Skip v2 block-storage tests when service is not found
  - syntax errors and undefined exceptions in service_description.py
  - Avoid dogpile.cache 0.7.0
  - Support non-public volume types
  - block_storage.backup func tests to use configurable timeout
  - Replace TaskManager with a keystoneauth concurrency
  - Add missing seperator between words
  - Add Octavia (load_balancer) provider API support
  - Replace neutron-grenade job with grenade-py3
  - Update link address for vendor support
  - Rework orchestration to add update preview
  - Explicit set capabilities in VolumeDetail and SnapshotDetail
  - new auth_url for ELASTX
  - Add missing py37 and corrected default envlist.
  - Add CRUD methods for Neutron Port Forwarding
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 0.17.2
  - Network: Add tag support for security group
  - Fix clustering profile type miss list operation
  - Add ipaddress and futures to lower-constraints
  - Allow cascade deletion of load balancer
  - Add ansible functional tests
  - Use valid filters to list floating IPs in neutron
  - Switch to providing created_at field for servers
  - Flavor: added is_public query parameter and description property
  - Add Magnum /certificates support
  - Add tests to verify behavior on '' in self link
  - Refactor _get_version_arguments
  - Hardcode v2.0 onto end of neutron endpoints
  - Add ability to pass data to create_object
  - Add connection backreference to proxy instances
  - Add python 3.6 jobs
  - meta: don't throw KeyError on misconfigured floating IPs
  - Fix DNS Recordset CRUD
  - Fix devstack tests
  - Fix typo in README.rst
  - Add release note for added masakari support
  - Finish migrating image tests to requests-mock
  - Remove default values of router's is_ha and is_distributed arguments
  - Allow explicitly setting enable_snat to either value
  - create_subnet: Add filter on tenant_id if specified
  - Add missing release note about vexxhost auth_url
  - Use 'none' auth plugin
  - Fix path for Limestone Networks vendor file
  - Move clustering additions from shade directories
  - Update create_object to handled chunked data
  - Update python-openstacksdk references to openstacksdk
  - Updated from global requirements
  - Add testing of availability_zones() "details" argument
  - Allow configuring status_code_retries and connect_retries via cloud config
  - pypy is not checked at gate
  - Allow not resolving outputs on get stacks
  - Convert image_client mocks in test_shade_operator
  - Fixing bug where original and new dicts would always be the same
  - Add Limestone Networks vendor info
  - Convert test_caching to requests-mock
  - Honor endpoint_override for get_session_client
  - fix doc title format error
  - Fix Magnum cluster update
  - Defer all endpoint discovery to keystoneauth
  - Add flag for disabling object checksum generation
  - Modify the unhelpful error message when delete network
  - Only send force parameter to live migration if supported
  - Implementing solution for 2002563 issue from story board
  - Add functional tests for Neutron DNS extension
  - close files after open in unit/base
  - Add ansible functional tests on stable-2.6
  - add missing attribute in LBaaS v2 Pool API
  - Improve Magnum cluster templates functions
  - Add 'port_details' to Floating IP
  - Fix TypeError in case of FloatingIP add and remove
  - Temporarily disable neutron-grenade
  - Clean up floating ip tests
  - Run os-client-config tests on sdk changes
  - fix tox python3 overrides
  - Temporarily disable osc-functional-devstack-tips
  - Bump default timeout values
  - Add timeout options for listener
  - Remove DataCentred from list of vendors
  - Add comment about W503 being skipped
  - fix misspelling of 'server'
  - Allow members to be set as "backup"
  - Replace old http links with the newest https ones in docs
  - Avoid globally modifying yaml library
  - Honor service-type aliases in config
  - Add image_format for VEXXHOST profile
  - Add vip_qos_policy_id options for loadbalancer
  - Turn OSC tips jobs non-voting
  - rename vars to defaults to allow overriding in ansible tests
  - Fix H103 Apache license header check
  - Add support for DNS attributes for floating IPs
  - Convert domain params tests to requests_mock
  - Fix resource not exist the resource.status error
  - Add set_provision_state and wait_for_provision_state for baremetal Node
  - Use defined version instead of service.version parameter
  - Run normalize_keys on config for session codepath
  - Rename service_key to service_type
  - baremetal: correct the default timeout in Node.set_provision_state
  - baremetal: refuse to inspect associated machines
  - Provide OpenStackConfigException backwards compat
  - Rename python-openstacksdk to openstacksdk in zuul.yaml
  - Invalid link of doc reference
  - Bugfix for block_storage not selecting the correct proxy
  - Add support for trunk ports and subports
  - Add create_directory_marker_object method
  - Handle Munch objects in proxies
  - Prepare for os-client-config wrapper
  - Switch VEXXHOST to 'v3password' auth_type
  - Pass default_microversion to adapter constructor
  - Add hypervisor details to hypervisors list if requested
  - Avoid raising exception when comparing resource to None
  - Added few image properties to Image class
  - Don't assume a full config dict
  - Don't wait for task in submit_task
  - Network: Add tag support for floating ip
  - Fix private_v4 selection related to floating ip matching
  - Add support for processing insecure
  - Add 409 ConflictException
  - Add missing swift docstrings
  - Remove D exclusions from flake8 config
  - Fix for passing dict for get_* methods
  - Strip the version prefix from the next link for pagination
  - Add get_volume_limits() support
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Change 'Member' role reference to 'member'
  - allow passing ansible variables to ansible tests
  - Reenable osc-functional-devstack-tips and neutron-grenade
  - Add task manager parameter to Connection
  - Support port binding extended attributes for querying port
  - Network: Add tag support for QoS policy
  - Fix openstack-inventory
  - Decode additional heat files
  - Add release note link in README
  - Change clustering example test create parameter
  - Remove the need for OpenStackConfig in CloudRegion
  - Functional test for set_tags on Neutron resources
  - Throw an error on conflicting microversion config
  - Update .gitreview for stable/rocky
  - Several improvements to resource.wait_for_status
  - Support to wait for load balancer to be ACTIVE
  - Add Magnum cluster support
  - Add instance_ha service
  - Redo role assignment list query filters
  - Adds Senlin support to openstacksdk
  - Implement signature generation functionality
  - Trivial: Update pypi url to new url
  - Drop bogus attributes from network port resource
  - Fix 'block_store' aliases define error
  - Add nodepool-functional-py35-src job
  - Fix F405 errors
  - Fix bugtracker and documentation references
  - Fix response always being False
  - Add /v3 to the auth_url for vexxhost
  - Enable bare metal unit tests
  - Modify the error message when unsetting gateway and setting FIP
  - add lower-constraints job
  - openstackcloud: properly handle scheduler_hints
- drop 0001-Let-enforcer.py-work-under-both-py2-and-py3.patch: upstream
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
  - adds 0001-Let-enforcer.py-work-under-both-py2-and-py3.patch
* Tue Feb 13 2018 cloud-devel@suse.de
- update to version 0.11.3 (bsc#1078607)
  - Fix image task uploads
  - Remove self argument from connect helper function
  - Add notes about moving forward
  - Fix batching for floating ips and ports
  - Remove openstack-tox-pypy jobs
  - v2 image update fix
  - Prefer links dicts for pagination
  - Remove meter service
  - Update for new docs PTI
  - Add ability to register non-official services
  - Fix py35 and pypy tox env
  - Do not apply format expansions to passwords
  - Provide compatibility for people passing raw sessions
  - Move shade and os-client-config python content
  - Remove metric service
  - Add group parameter to create_server
  - Remove use of tox-siblings role
  - Remove -U from pip install
  - Add tag support to create_stack
  - Add helper property to get the current user id
  - Add resource2/proxy2 wrappers with deprecations
  - Add clustering guides cluster file, examples cluster code
  - Rename resource2 and proxy2 to resource and proxy
  - Add pools attribute to load balancer heath monitor
  - Move profile helper method to openstack.profile
  - Fix TypeError for overrided get methods
  - Implement availability_zone_hints for networks and routers.
  - Add cluster support force delete parameter
  - Rename CloudConfig to CloudRegion
  - Add betacloud to the vendors
  - Move task_manager and adapter up a level from cloud
  - Use version definition from openstack.version
  - Remove inner_exceptions plumbing
  - Allow domain_id for roles
  - Add deprecation warnings to profile
  - Add block_store support single volume display image message
  - Use Zuul v3 fetch-subunit-output
  - Change update/create method options
  - Added nat_source flag for networks.
  - Use devstack functional test base job
  - Clean up the release notes a bit
  - Adds get encrypted password support
  - Remove legacy client factory functions
  - Update the shade-merge document
  - Move role normalization to normalize.py
  - Clean up a bit after the mapping inversion
  - Add _query_mapping to identity resources
  - Port wait_for_ methods to use iterate_timeout
  - Complete move of baremetal machine tests
  - Cleanup objects that we create on behalf of images
  - Consume publish-openstack-sphinx-docs
  - Handle resource deletion properly
  - Add clustering guides node file, examples node code
  - Fix typo in the external service loader code
  - Make sure we use config defaults in profile compat code
  - Add ability to work in other auth contexts
  - Remove the deprecated "giturl" option
  - Remove python-ironicclient
  - Add server-side names to query param checking
  - Temporarily disable volume and os_image functional tests
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Move openstack_cloud helper functions
  - Avoid default mutable values in arguments
  - Treat clouds.yaml with one cloud like envvars
  - Invert the attribute mapping
  - Start using Connection in openstack.cloud
  - modify spelling error of resource
  - change spell error
  - Updated from global requirements
  - Remove setting of version/release from releasenotes
  - Make floating IP to be prefered over fixed when looking for IP
  - Add subnet_id property for FloatingIP
  - Replace clustering examples code cluster to clustering
  - Remove resource and proxy
  - Add method to cleanup autocreated image objects
  - Raise error when supplying invalid query params
  - Fix magnum functional test
  - Add supported method for checking the network exts
  - Support filtering servers in list_servers using arbitrary parameters
  - Add function to make CloudRegion from session
  - Add jobs for Zuul v3
  - Make the get_service_type() overrides tolernat of no defaults
  - Migrate to testtools for functional tests
  - resource: don't early terminate list
  - Pass through all_projects for get_server
  - Adds support to retrieve cinder backend pools information
  - Remove reference to context-managers from release note
  - fix misspelling of 'configuration'
  - Update docs and pep8 tox environments
  - Update Release Notes links and add bugs links
  - Add FloatingIP qos_policy_id attribute
  - Rationalize logging helpers and docs
  - Remove bogus and unneeded role from job definition
  - Re-enable octavia functional tests
  - Fixed a few nits in the README
  - Sort image update results before comparing
  - Rework config and rest layers
  - Stop osSDK mangling Swift metadata keys
  - Update make_rest_client to work with version discovery
  - Make meta.find_best_address() more generic
  - Add reno for tag support on heat stacks
  - Throw OpenStackCloudCreateException on create errors
  - Shift image tests from test_operator
  - Baremetal NIC list should return a list
  - Add a descriptor object for each service proxy
  - Protect against p_opt not having prompt attribute
  - Add clustering guides receiver file,examples receiver code
  - Update .gitreview for stable/queens
  - Add osc-tox-unit-tips jobs
  - Allow to pass filters like domain to find_project/user
  - Avoid tox_install.sh for constraints support
  - Remove name from zuul project stanza
  - Remove ansible functional tests for now
  - Add OSC functional tips jobs
  - Document current_user_id in a release note
  - Fix releasenotes builds
  - Fix regression for list_router_interfaces
  - Add clustering guides file, Examples code.
  - Update type conversion to handle subtypes more better
  - Fix an error about listing projects in connection doc
  - Fix clustering detach policy describe error
  - Add retry logic mechanism
  - Remove message v1 support
  - Ensure Connection can be made from keyword arguments
  - Image should be optional
  - Set empty Tag list if Network Tag API extension not supported
  - Handle glance image pagination links better
  - Add method to set bootable flag on volumes
  - Fix issue with missing url parameters
  - Add some docs about not using Profile
  - Migrate object_store to resource2/proxy2
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 0.9.19
  - Update load_balancer for v2 API
  - Introduce Member for Octavia (load balancing)
  - Fix comment in services function
  - Remove dead links about OpenStack RC file
  - Fix stack_file function return body
  - Cleanup test-requirements
  - Fix title in Network Agent resource doc
  - Add parameter_groups and conditions params for StackTemplate
  - Introduce Health Monitor for Octavia
  - fix the bug that cannot create a listener by openstacksdk
  - Introduce L7Rule for Octavia (load balancing)
  - Add required pool_id property to HealthMonitor
  - Fix some typos
  - Replace six.iteritems() with .items()
  - Add doc8 rule and check doc/source files
  - Add support for network quota details command
  - Allow filtering network ports by fixed_ips
  - Introduce Pool for Octavia (load balancing)
  - Update links in README
  - Update links in CONTRIBUTING.rst
  - Introduce Listener for Octavia (load balancing)
  - Fix octavia l7rules
  - Update external links which have moved
  - Introduce L7Policy for Octavia (load balancing)
  - Unify style of 'domain' field
  - Support to node-adopt and node-adopt-preview
  - fix the bug that cannot create a pool by openstacksdk
  - Add config param for cluster object
  - Add getting of QoS rule type details
  - Support node-adopt/preview CLI
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 0.9.17
  - Fix document warnings
  - Add port property: trunk_details
  - Introduce Base for Octavia (load balancing)
  - Add compute support server migrate operation
  - Remove discover from test-requirements
  - Use https instead of http in cluster examples
  - Add is_profile_only to Cluster resource
  - Fix network quota test so it works on gate
  - Add compute support server backup operation
  - Cleanup various Sphinx warnings during doc build
  - Add wait_for_xxx methods to cluster proxy
  - Add new parameter "is_default" to Network QoS policy.
  - Fix the network service provider test
  - Filtering support by is_router_external to network resource
  - Reorganize image docs
  - Reorganize telemetry docs
  - Add cluster_operation and node_operation
  - Fix the agent add remove test
  - Remove get_service method from compute
  - Enable warnings_as_errors in doc enforcer
  - Add StackFiles resource to orchestration v1
  - Update the image used for functional tests
  - Fix the network floating ip test for get
  - Correct Network `ports` query parameters
  - Fix the telemetry statistics test
  - Updated from global requirements
  - Remove two remaining doc warnings
  - Add data plane status support to Network Port obj
  - Add 'project_id' to Server query parameters
  - Deprecate Message v1
  - Privatize session instance on Proxy subclasses
  - Add StackEnvironment resource to orchestration v1
  - keystone api v2.0 does not paginate roles or users
  - Add vlan_transparent property to network resource
  - the role resource should not have put_create=True
  - Reorganize identity docs
  - Fix the network flavor disassociate method
  - Reorganize network docs
  - Add params to ClusterDelNodes action
  - Fix the network auto allocate validate
  - Reorganize orchestration docs
  - Added server console output method
  - functional tests: minor cleanup
  - update params about cluster filter event
  - Shift some compute attributes within request body
  - Fix the network quota tests
  - Revert "HAProxy uses milliseconds ..."
  - Add support for volume attachments in compute v2
  - Find floating ip by ip address
  - Port database v1 to resource2
  - Update intersphinx linking to python.org
  - Get endpoint versions with domain scope session
  - Fix exception parsing error
  - Trivial: fix Template resource in orchestration
  - Reorganize compute docs
  - Add direction field to QoS bandwidth limit.
  - Fix doc build if git is absent
  - Add 'service list' resource for senlin
  - Added project role assignment
  - Fix the telemetry sample test
  - Implement metric docs
  - Port metric v1 to resource2
  - Fix the nextwork agent add remove test
  - Reorganize object_store docs
  - Add image download example
  - Fix the service profile meta info test
  - Fix the object store set metadata functional test
  - Change version of hacking in test-requirements
  - Replace assertRaisesRegexp with assertRaisesRegex
  - Add cluster support receiver update operation
  - Fix function test for compute images
  - Update devstack config to point to a valid image
  - Adjust some proxy method names in cluster
  - Remove unsupported telemetry create_sample method
  - Add 'tags' property to orchestration stack
  - Implement message docs
  - Remove support for py34
  - Add compute support server live migrate operation
  - Add docs for volume_attachment compute methods
  - Support profile-only to cluster update
  - Expose OS-EXT-SRV-ATTR:{hypervisor_hostname,instance_name} for Server.
  - Port identity v2 to resource2
  - Port image v1 to resource2
  - Remove unnecessary get_id call in _prepare_request
  - Cleanup more Sphinx warnings during doc build
  - Reorganize bare_metal docs
  - Enable streaming responses in download_image
  - Add network flavor associate, disassociate to SDK
  - Reorganize workflow docs
  - Fix cluster action list filter
  - Reorganize block store docs
  - Remove old telemetry capability
  - Adjust some proxy method names in bare_metal
  - Correct a copy/paste mistake in a docstring
  - Fix py3 compatibility (dict.iteritems()) in object_store
  - Reorganize key_manager docs
  - Expose ha_state property from HA enabled L3 Agents.
  - Remove type restrict of block_device_mapping
  - Reorganize database docs
  - Remove unnecessary coding format in the head of files
  - Add missing attribute to Subnet resource
  - Fix problem with update including id
  - Network tag support
  - Deprecate "wait_for" methods on ProxyBase
  - StackTemplate resource for orchestration
  - Reorganize cluster docs
  - Add get_stack_* methods to documentation
  - Enforce inclusion of pulic proxy methods in docs
  - Specify alternate_id in network quota
  - Avoid imports in openstack/__init__.py
  - Allow router related functions to receive an ID
  - Fix update_image unsupported media type
  - Port unversioned Version resources to resource2
  - Clean up some errant doc warnings/errors
  - Deprecate port and ping methods in Network proxy
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 0.9.13:
  - Add QoS bandwidth limit rule object and CRUD commands.
  - Add reset_state api for compute
  - Add new function for router-gateway
  - Add user_id in profile resource.
  - Add more server operations based on Nova API
  - Add filter "user_id" for cluster receiver list
  - Modified DHCP/Network Resource
  - Add QoS support to Network Port object.
  - Add filters to the network proxy agents() method
  - Fix error messages are not displayed correctly
  - Generalize endpoint determination
  - Fix Setting Quotas in Neutron
  - Rebase telemetry resources to resource2/proxy2
  - Add list method and query support for cinder volume and snapshot
  - Rebase network resources onto resource2 (1)
  - Support for node replace in cluster service
  - Provide better fallback when finding id values
  - Add QoS DSCP marking rule object and CRUD commands.
  - avoid usage of keystoneauth1 sessions
  - Chassis resource for bare-metal service
  - Rebase network proxy to proxy2
  - Update homepage with developer documentation page
  - Fix cluster query mapping
  - compute/v2/server: add ?all_tenants=bool to list
  - Add QoS minimum bandwidth rule object and CRUD commands.
  - Add filters provider-* to the network proxy networks() method
  - Revert "Event list can not display "timestamp"
  - Add filter options to the network proxy address_scopes() method()
  - Updated from global requirements
  - Prepare for baremetal API implementation
  - Fix connection init when session is provided
  - Document the `synchronized` parameter.
  - Obtain Image checksum via additional GET
  - Base for workflow service (mistral)
  - Driver resource for bare-metal service
  - Corrections in DHCP Agent Resource listing.
  - Rebase keystone v3 proxy to proxy2
  - Add support_status to policy type and profile type
  - Fix 'config_drive' and 'networks' for compute server
  - Add user_id in resource class Action/Node
  - Add support for network Service Flavor Profile
  - Modified Metering Rule base_path
  - Rebase network resources to resource2 (4)
  - Add docs for the workflow service
  - Add "sort" in policy binding list
  - Add limit and marker to QueryParameters class
  - Fix telemetry/metering service version
  - Initial docs for bare-metal service
  - Port resource for bare-metal service
  - Add project_id field to cluster's policy and profile
  - Add resource for DHCP Agent.
  - Rebase keystone resources onto resource2
  - Add 'project_id' field to volume resource
  - Proxy module for bare-metal service
  - Event list can not display "timestamp"
  - Support to delete claimed message
  - Remove beta label for network segment resource
  - Add standard attributes to the core network resources
  - Fix the issue non-admin user failed to list trusts
  - Add filters "policy_type" and "policy_name" for policy binding list
  - Document network resource query filters used by OSC
  - Adjust router add/remove interface method names
  - Remove dead code
  - Add workflow service (mistral)
  - Add QoS rule type object and CRUD commands.
  - Add Python 3.5 classifier and venv
  - Enable bare-metal service
  - Add user_id in resource class Policy
  - Fix the issue that 'type' field is missing in profile list
  - Display neutron api error message more precisely
  - Add filter "enabled" for cluster-policy-list
  - Add missing query parameters to compute v2 Server
  - Add support for Role resource in Identity v3
  - Fix metadata property of Senlin node resource
  - Add QoS support to Network object.
  - Clarify argparse connections
  - Node resource for bare-metal service
  - Add network segment create, delete and update support
  - Add filters to the router proxy routers() method
  - Rebase network resources to resource2 (3)
  - Add project ID in QuotaDefault requests
  - Added is_shared resource to Metering Label
  - Fix problem about location header in Zaqar resource2
  - Add 'project_id' field to cluster's action resource
  - Add auto-allocated-topology to SDK
  - Network L3 Router Commands
  - Add support for network Flavor
  - Add resources for Service Provider
  - Add support for filter "status" in node list
  - Add extended Glance Image properties
  - Add service_type resource to Subnets
  - Add filter mac_address to the network proxy ports() method
  - Revert "Display neutron api error message more precisely"
  - Rebase network resources onto resource2 (2)
  - Modified Metering base_path
  - PortGroup resource for bare-metal service
  - Fix error in node action
  - Add dns-domain support to Network object.
  - Add 'dependents' property to Node and Cluster class
* Sun Oct  2 2016 dmueller@suse.com
- revert last change (go back to 0.9.5, which is Newton)
* Fri Sep 23 2016 mjura@suse.com
  update to version 0.9.7
  * Revert "Event list can not display "timestamp"
  * Event list can not display "timestamp"
  * Add project_id field to cluster's policy and profile
  * Fix the issue non-admin user failed to list trusts
  * Fix error in node action
  * compute/v2/server: add ?all_tenants=bool to list
  update to version 0.9.6
  * Add extended Glance Image properties
  * Fix connection init when session is provided
  * Rebase keystone v3 proxy to proxy2
  * Fix 'config_drive' and 'networks' for compute server
  * Fix cluster query mapping
  * Rebase keystone resources onto resource2
  * Add new function for router-gateway
  * Obtain Image checksum via additional GET
  * Adjust router add/remove interface method names
  * Add 'dependents' property to Node and Cluster class
  * Add QoS rule type object and CRUD commands
  * Add QoS bandwidth limit rule object and CRUD commands
  * Add QoS DSCP marking rule object and CRUD commands
  * Add QoS minimum bandwidth rule object and CRUD commands
  * Add network segment create, delete and update support
  * Rebase telemetry resources to resource2/proxy2
  * Fix telemetry/metering service version
  * Fix the issue that 'type' field is missing in profile list
* Fri Sep  2 2016 tbechtold@suse.com
  update to version 0.9.5
  * Updated from global requirements
  * Fix issue "SDKException: Connection failure that may be retried."
* Tue Aug 30 2016 tbechtold@suse.com
  update to version 0.9.4
  * Add SoftwareDeployment resource to orchestration
  * Add policy validation for senlin
  * Fix cluster resource in cluster service
  * Add API microversion support
  * Add collect_cluster_attrs API to cluster service
  * Remove update_flavor method from compute
  * Fix problems about location header in resource2
  * Add SoftwareConfig resource to orchestration
  * _alternate_id should return a server-side name
  * Add support for message resource of Zaqar v2 API
  * Relocate alarm service into a submodule
  * Add support for claim for Zaqar V2 API
  * Add QoS policy object and CRUD commands.
  * Replace _transpose_component with _filter_component
  * Tweak endpoint discovery for apache-style services
  * Improve docstring for some resource2 methods
  * Add services operations into compute service
  * Add 'check_stack' operation to proxy
  * Fix test_limits functional test failure
  * Add profile validation for senlin
  * Add force-delete into compute service
  * Make end-user modules accessible from top level
  * Fix orchestration service initialization
  * HAProxy uses milliseconds for its timeout values.
  * Rebase cluster service to resource2/proxy2
  * Rebase orchestration to resource2/proxy2
  * Support fetching network project default quota
  * Add support for Zaqar V2 queue resource
  * Fix nova server image and flavor
  * Add 'to_dict()' method to resource2.Resource
  * Minor network RBAC policy updates
  * Add template validation support to orchestration
  * Refactor Key Manager for resource2
  * Get endpoints directly from services
  * Refactor image v2 to use resource2/proxy2
  * Updated from global requirements
  * Add support for subscription for Zaqar V2 API
  * Expose 'requires_id' to get_xxx proxy functions
* Fri Jul 22 2016 tbechtold@suse.com
- update to version 0.9.0:
  * Refactor compute for new resource/proxy
  * Allow alternate_id to be accessed directly
  * Add neutron rbac support
  * Updated from global requirements
  * Add temporary test_proxy_base2
  * Add segment_id property to subnet resource
  * Allow resources to check their equality
  * Remove type=timestamp usages
  * Cluster user guide - part 2
  * Move version definition
  * Fix clustering event properties
- update _service and switch to upstream .spec file
* Tue May  3 2016 dmueller@suse.com
- update to 0.8.5:
  * Trivial: Fix typo in update_port() comment
  * Support client certificate/key
  * Add network resource properties
  * Updated from global requirements
  * Properly handle overridden Body properties
* Fri Apr  8 2016 tbechtold@suse.com
- update to 0.8.4:
  * Refactor Resource to better serve Proxy
  * Consistent resource.prop for timestamps and booleans (cluster
  * Add address scope CRUD
  * Consistent resource.prop for timestamps and booleans (object store)
  * Consistent resource.prop for timestamps and booleans (network)
  * Consistent resource.prop for timestamps and booleans (identity)
  * Cluster user guide - first step
  * Consistent resource.prop for timestamps and booleans (orchestration)
  * Consistent resource.prop for timestamps and booleans (telemetry)
  * Fix image member apis
  * Fix content-type for swift upload
  * Fix key manager secret resource object
  * Consistent resource.prop for timestamps and booleans (key manager)
  * Consistent resource.prop for timestamps and booleans (image)
  * Make metadata handling consistent in Compute
  * Fix coverage configuration and execution
  * Consistent resource.prop for timestamps and booleans (compute)
  * Fix functional tests
  * Add/Remove port interface to a router
  * Consistent resource.prop for timestamps and booleans (block store)
  * Consistent resource.prop for timestamps and booleans (metric)
* Mon Mar 14 2016 tbechtold@suse.com
- update to 0.8.1:
  * Add Hypervisor support to Compute Service
- Update description
- Add BuildRequires for testing but testing is still disabled.
* Wed Mar  2 2016 tbechtold@suse.com
- update to 0.8.0:
  * Add Nova server group resource
  * Make metadata handling consistent in Object Store
  * Updated from global requirements
  * Override delete function of senlin cluster/node
  * Basic resource.prop for ID attributes (message)
  * Basic resource.prop for ID attributes (cluster)
  * Adding Check/Recover Actions to Clusters
  * Basic resource.prop for ID attributes (block store)
  * Basic resource.prop for ID attributes (orchestration)
  * Fix compute tests for resource.prop ID attributes
  * Basic resource.prop for ID attributes (compute)
  * Basic resource.prop for ID attributes (image)
  * Basic resource.prop for ID attributes (identity)
  * Basic resource.prop for ID attributes (telemetry)
  * Update attributes uses hard coded id
  * Adding check/recover actions to cluster nodes
  * Basic resource.prop for ID attributes (network)
  * Remove 'date' from Object resource
  * Make functional test resources configurable
  * Fix Port resource properties
  * Refactor profile set_ methods
  * Add UNIXEpoch formatter as a type for properties
  * Update create_network function in test_network
  * Documentation for cluster API and resources
  * Resource object attributes not updated on some interfaces
  * Add ISO8601 formatter as a type for properties
  * Add LoadBalancer vip_port_id and provider properties
  * Raise NotFound exception when get a deleted stack
  * Updated from global requirements
  * download_object/get_object must have the same API
  * Map KSA exception to SDK exceptions
  * Fix URLs for CLI Reference
  * Updated from global requirements
  * Send keystoneauth a better user-agent string
  * Add network availability zone support
  * Allow resource get to carry query string
  * Rework cluster API
  * Skip test class unless a service exists
  * Add attribute 'location' to base resource
  * Add preview_stack for orchestration
  * Update Quota documentation and properties
  * Update Subnet Pools Documentation
  * Update router's functional tests to validate is_ha property
  * Updated from global requirements
  * Use assertTrue/False instead of assertEqual(T/F)
  * Remove status property from LBaaS resources
  * Add functional tests for DVR router
  * Add missing Listener resource properties
  * Better support for metadata in Compute service
  * Add image user guide
  * s/save/download/
  * Replace assertTrue(isinstance()) with assertIsInstance()
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Add support for availability zone request
  * Add proxy methods for node actions (cluster)
  * Rename timestamp fields for cluster service
  * Add cluster actions to cluster proxy
  * Fix docstring of resource_id parameter in resource module
  * Fix server action resource call
  * Correct response value in resource unittests
  * Raise not found error if stack is deleted when find_stack
  * Add Receiver resource to cluster service
  * Add Subnet Pool CRUD
  * remove python 2.6 trove classifier
  * Add Quota RUD and missing properties
  * Add 'resize' action to cluster
  * Return None when getting an attr which is None when using resource.prop()
  * Add Network mtu and port_security_enabled properties
  * Support block_store types where IDs are taken
  * Remove requests from requirements
  * cluster: Use typed props instead of *_id
  * Updated from global requirements
  * Rename key_management to key_manager
  * Replace 'value' arguments in telemetry proxy
  * Add Port port_security_enabled property
  * Replace 'value' arguments in orchestration proxy
  * Replace 'value' arguments in object_store proxy
  * Replace 'value' arguments in network proxy
  * Replace 'value' arguments in key_management proxies
  * Replace 'value' arguments in image proxies
  * Fix exceptions to catch for ignore_missing
  * Updated from global requirements
  * Add admonition to telemetry code
  * Add Router ha, distributed and routes properties
  * Fix "report a bug" launchpad project
  * Add PolicyType resource for clustering
  * Add 'ProfileType' resource for senlin
  * block_store and cluster: replace 'value' arguments
  * Add cluster-policy binding resource to Senlin
  * Skip orchestration functional tests
  * Replace 'value' arguments in identity proxies
  * Replace 'value' arguments in database proxy
  * Replace 'value' arguments in compute proxy
  * Update doc link in README
  * Remove oslosphinx
  * Skip broken functional tests
  * Delete key pair and server for Compute example
  * Fix 400 error in compute examples
  * Fix post test hook script
  * Remove the Metric proxy
  * Remove an extra dangling doc reference to CDN
  * Remove incomplete CDN code
  * Fix failing compute example
  * Updated from global requirements
  * Updated from global requirements
  * Add identity user guide
  * Doc: Add instructions for creating cloud.yaml
  * Replace stackforge with openstack
  * Add BuildInfo resource to cluster service
  * Updated from global requirements
  * Add network user guide
  * Add authorize method to Connection
  * Avoid Pool object creating in pool_member functional calls
  * Fix cluster action api invocations
  * Add rebuild_server function call
  * Replace 'MagicMock' with 'Mock'
  * Updated from global requirements
  * Trivial: Fix a typo in resource.py
  * Add server resize function calls
  * Make nova server_interface function calls work
  * Fix typo in action test case
  * Add event resource for senlin(cluster) service
  * Remove missing capability
  * Remove some dead exception types
  * Fix senlin update verb
  * Replace 'MagicMock' with 'Mock'
  * Publicize the _convert_id call of Resource class
  * Try running examples tests on gate
  * Add documentation for testing examples
  * Cleanup doc references to past modules
  * Use consistent argument names for find proxies
  * find_security_group_rule does not find by name
  * Updates doc enviro to use OpenStack Docs theme
- add _service file
- update Requires according to requirements.txt
* Tue Dec  8 2015 bwiedemann@suse.com
- initial version 0.7.1
